@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11771 2019-11-01 08:29:32Z Andy $
+# $Id: __init__.py 11882 2020-01-19 13:27:40Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $ (last)
-# $Date: 2019-11-01 16:29:32 +0800 (週五, 01 十一月 2019) $
-# $Revision: 11771 $
+# $Author: Lavender $ (last)
+# $Date: 2020-01-19 22:27:40 +0900 (週日, 19 一月 2020) $
+# $Revision: 11882 $
 
 from __future__ import print_function
 
@@ -25,7 +25,7 @@ import importlib
 from .Patch import attachURLs, attachDebugURLs
 from .Util import update, populateEnvToSettings
 
-from Iuppiter.DjangoUtil import extendInstalledApps, DJANGO_VERSION
+from Iuppiter.DjangoUtil import extendInstalledApps, DJANGO_VERSION, extendMiddlewareClasses
 
 # Default SERVER_MODE values.
 DEVELOPMENT = 1
@@ -725,11 +725,16 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'des',
         'Iuppiter.extension',
         'Iuno.deploy',
+        'Iuno.ban',
     )
+    ADDING_MIDDLEWARE = [
+        'Iuno.ban.middleware.BanSpamMiddleware',
+    ]
     installed = settingsDict['INSTALLED_APPS']
     keys = [k for k in installed if k.startswith('django.contrib')]
     extendInstalledApps(settingsDict, ADDING_INSTALLED_APPS,
                         key=list(keys)[-1])
+    extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE)
     #=========================================================================
 
     #=========================================================================
