@@ -24,7 +24,6 @@ import six
 from django.core.management.base import BaseCommand, CommandError
 from django.core.management import get_commands
 from django.template.loader import get_template
-from django.template import Context
 
 from Iuppiter.Logging import createLogger
 
@@ -71,11 +70,11 @@ class Command(BaseCommand):
             command = command.replace("'", "'\\''")
                 
             temp = get_template("deploy/Cron.sh")
-            c = Context({
+            c = {
                 "command": command,
                 "time": time,
                 "jobName": jobName,
-            })
+            }
             
             shell = temp.render(c).replace("\r\n", "\n")
             
