@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11881 2020-01-19 12:01:02Z Lavender $
+# $Id: views.py 11894 2020-02-04 12:08:11Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-19 20:01:02 +0800 (週日, 19 一月 2020) $
-# $Revision: 11881 $ 
+# $Date: 2020-02-04 21:08:11 +0900 (週二, 04 二月 2020) $
+# $Revision: 11894 $ 
 
 import json
 import logging
@@ -51,12 +51,7 @@ from oscar import VERSION
 
 from Iuppiter.Encoding import utf8
 from Iuppiter.Encryption import Encryptor
-from Iuppiter.DjangoUtil import DJANGO_VERSION
-
-if DJANGO_VERSION <= 20000: # 2.0.0:
-    from django.core.urlresolvers import reverse
-else:
-    from django.urls import reverse
+from Iuppiter.DjangoUtil import DJANGO_VERSION, reverse
 
 from Iuno.shop import forms
 from Iuno.shop import buildAPIForm
@@ -1021,10 +1016,15 @@ def sendPaymentForm(request):
             raise Http404()
         request.session['preBasketId'] = request.basket.id
         request.basket.freeze()
+        d = base64.b64decode(formData)
+        form = encryptor.decrypt(d)
+        if six.PY3:
+            form = form.decode()
+        
         return render(
                 request, 
                 "shop/payment/PaymentRedirect.html", 
-                {'form': encryptor.decrypt(base64.b64decode(formData)),}
+                {'form': form,}
             )
     else:
         raise Http404()
